@@ -1,6 +1,6 @@
 
 
-inlineCxxPlugin <- Rcpp:::Rcpp.plugin.maker(
+inlineCxxPlugin <- Rcpp::Rcpp.plugin.maker(
     include.before = paste("#include<RcppEigen.h>",
                            "#include<covafill/Tree>",
                            "",
