@@ -49,16 +49,24 @@ typename covafill<scalartype_>::vectortype covafill<scalartype_>::operator()(vec
 
   // Create (sparse) matrix of weights
   sparsematrixtype W(nobs,nobs);
+  vectortype kde(1);
+  kde(0) = scalartype(0.0);
   for(int i = 0; i < nobs; ++i){
     if(calcNorm(x0,coordinates.row(i)) > excludeRadius){
       scalartype wi = getWeight(x0,coordinates.row(i));
+      kde(0) += wi / nobs;
       if(wi > 0)
 	W.insert(i,i) = wi;
     }
   }
+  if(p == -1){
+    return kde;
+  }
 
   // Calculate (dense) design matrix for least squares (nobs x dim)
-  int lsdim = 1 + dim;
+  int lsdim = 1;
+  if( p >= 1)
+    lsdim += dim;
   if(p >= 2)
     lsdim += 0.5 * dim * (dim + 1);
   if(p >= 3)
@@ -70,8 +78,9 @@ typename covafill<scalartype_>::vectortype covafill<scalartype_>::operator()(vec
     // First is the intercept
     X(i,0) = 1.0;
     // Then (x-x0)
-    for(int j = 1; j < 1+dim; ++j)
-      X(i,j) = xtmp(j-1);
+    if(p >= 1)
+      for(int j = 1; j < 1+dim; ++j)
+	X(i,j) = xtmp(j-1);
     // Finally (x-x0)^T(x-x0) if p == 2; i.e. the interactions
     if(p >= 2){
       int indx = 1+dim;
@@ -90,6 +99,7 @@ typename covafill<scalartype_>::vectortype covafill<scalartype_>::operator()(vec
     }
   }
 
+
   // Calculate weighted least squares estimates
   matrixtype XTW = X.transpose() * W;
   matrixtype XWXinv = (XTW * X).inverse();
@@ -109,8 +119,8 @@ typename covafill<scalartype_>::vectortype covafill<scalartype_>::operator()(vec
 
   if(returnAll)
     return beta;
-  return beta.segment(0,1+dim);
-};
+  return beta.segment(0,1+dim*(p>0));
+}
 
 template<typename scalartype_>
 typename covafill<scalartype_>::vectortype covafill<scalartype_>::operator()(vectortype x0, bool returnAll) const {
@@ -126,16 +136,31 @@ typename covafill<scalartype_>::vecvectype covafill<scalartype_>::operator()(vec
   // Create (sparse) matrix of weights
   int NnotZero = 0;
   sparsematrixtype W(nobs,nobs);
+  vectortype kde(1);
+  kde(0) = scalartype(0.0);
+
   for(int i = 0; i < nobs; ++i){
       scalartype wi = getWeight(x0,coordinates.row(i));
+      kde(0) += wi / nobs;
       if(wi > 0){
 	W.insert(i,i) = wi;
 	NnotZero++;
     }
   }
 
+  if(p == -1){
+    vecvectype reskde(2);
+    reskde(0) = kde;
+    vectortype tmp(1);
+    tmp(0) = NAN; // Not the best solution
+    reskde(1) = tmp;
+    return reskde;
+  }
+
   // Calculate (dense) design matrix for least squares (nobs x dim)
-  int lsdim = 1 + dim;
+  int lsdim = 1;
+  if(p >= 1)
+    lsdim += dim;
   if(p >= 2)
     lsdim += 0.5 * dim * (dim + 1);
   if(p >= 3)
@@ -147,8 +172,9 @@ typename covafill<scalartype_>::vecvectype covafill<scalartype_>::operator()(vec
     // First is the intercept
     X(i,0) = 1.0;
     // Then (x-x0)
-    for(int j = 1; j < 1+dim; ++j)
-      X(i,j) = xtmp(j-1);
+    if(p >= 1)
+      for(int j = 1; j < 1+dim; ++j)
+	X(i,j) = xtmp(j-1);
     // Finally (x-x0)^T(x-x0) if p == 2; i.e. the interactions
     if(p >= 2){
       int indx = 1+dim;
@@ -177,9 +203,9 @@ typename covafill<scalartype_>::vecvectype covafill<scalartype_>::operator()(vec
   // Calculate covariance of estimates
   matrixtype R = observations.matrix() - X * beta.matrix();
   matrixtype shat = (matrixtype)(R.transpose() * W) * R;
-  shat /= NnotZero-lsdim;
-
-  matrixtype cova = XWXinv * shat(0,0);
+  scalartype tr = ((matrixtype)W).trace() - (tmp * W * X).trace();
+  shat /= tr;
+  matrixtype cova = shat(0,0) * XWXinv * (X.transpose() * (W * W) * X) * XWXinv;
   vectortype covvec(Eigen::Map<vectortype>(cova.data(), cova.cols()*cova.rows())); 
 
   vecvectype res(2);
@@ -195,7 +221,7 @@ typename covafill<scalartype_>::vecvectype covafill<scalartype_>::operator()(vec
     res(1) = cova.diagonal().segment(0,1+dim);
   }
   return res;
-};
+}
 
 
 
